<?php

namespace Drupal\search_api_opensolr\Plugin\SolrConnector;

use Drupal\Component\Utility\NestedArray;
use Drupal\Core\Form\FormStateInterface;
use Drupal\search_api_opensolr\Traits\OpensolrKeyDependencyTrait;
use Drupal\search_api_solr\SolrConnector\BasicAuthTrait;

/**
 * OpenSolr connector.
 *
 * @SolrConnector(
 *   id = "basic_auth_opensolr",
 *   label = @Translation("Opensolr with Basic Auth (recommended)"),
 *   description = @Translation("A connector usable for Solr installations managed through opensolr that uses basic auth.")
 * )
 */
class BasicAuthOpensolrSolrConnector extends OpensolrSolrConnector {

  use OpensolrKeyDependencyTrait;
  use BasicAuthTrait {
    buildConfigurationForm as traitBuildConfigurationForm;
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = $this->traitBuildConfigurationForm($form, $form_state);
    $form['auth']['#description'] = $this->t('Your <strong>opensolr</strong> index security information is <strong>prefilled automatically</strong>. If you changed it in opensolr, simply re-save this form. You can also use Search API opensolr seucurity module to manage authentication security.');
    $credentials = $this->openSolrConfig->getApiCredentials();
    $form['auth']['username']['#default_value'] = $credentials['email'];
    $form['auth']['username']['#access'] = FALSE;
    $form['auth']['password']['#default_value'] = $credentials['api_key'] ?? $credentials['api_key_raw'];
    $form['auth']['password']['#access'] = FALSE;
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::validateConfigurationForm($form, $form_state);
    // Override the default values if the index values are different.
    $coreName = $form_state->getValue(['opensolr', 'index']);
    if (empty($coreName)) {
      $form_state->setErrorByName('opensolr', $this->t('No valid index was selected'));
    }
    else {
      $core = $this->openSolrIndex->getCoreInfo($coreName);
      $username = NestedArray::getValue($core, ['info', 'auth_username']);
      $password = NestedArray::getValue($core, ['info', 'auth_password']);
      if (empty($username) && empty($password)) {
        $form_state->setErrorByName('opensolr', $this->t('Failed to retrieve the core auth information.'));
      }
      else {
        $form_state->setValue('auth', [
          'username' => $username,
          'password' => $password,
        ]);
      }
    }
  }

}
